==> jc-1.4.0.tar.gz: java/nio/charset/CharacterCodingException.h <==
// public class java.nio.charset.CharacterCodingException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_nio_charset_CharacterCodingException_H_
#define _JC_java_nio_charset_CharacterCodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_charset_CharacterCodingException$sub_refs	_jc_java_nio_charset_CharacterCodingException$sub_refs;
typedef struct _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	_jc_java_nio_charset_CharacterCodingException$sub_nonrefs;
typedef struct _jc_java_nio_charset_CharacterCodingException$refs	_jc_java_nio_charset_CharacterCodingException$refs;
typedef struct _jc_java_nio_charset_CharacterCodingException$nonrefs	_jc_java_nio_charset_CharacterCodingException$nonrefs;
typedef struct _jc_java_nio_charset_CharacterCodingException$object	_jc_java_nio_charset_CharacterCodingException$object;

typedef const struct _jc_java_nio_charset_CharacterCodingException$vmethods	_jc_java_nio_charset_CharacterCodingException$vmethods;
typedef const struct _jc_java_nio_charset_CharacterCodingException$vtable	_jc_java_nio_charset_CharacterCodingException$vtable;
typedef const struct _jc_java_nio_charset_CharacterCodingException$vtype	_jc_java_nio_charset_CharacterCodingException$vtype;

// Constructors
extern void _jc_java_nio_charset_CharacterCodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CharacterCodingException$object *);

// Virtual methods structure
struct _jc_java_nio_charset_CharacterCodingException$vmethods {
};

// Vtable
struct _jc_java_nio_charset_CharacterCodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
};

// Vtype
struct _jc_java_nio_charset_CharacterCodingException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CharacterCodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CharacterCodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CharacterCodingException$refs {
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CharacterCodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CharacterCodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
};

// Object instance structure
struct _jc_java_nio_charset_CharacterCodingException$object {
	_jc_java_nio_charset_CharacterCodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CharacterCodingException$vtype	*vtype;
	_jc_java_nio_charset_CharacterCodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CharacterCodingException$vtype _jc_java_nio_charset_CharacterCodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CharacterCodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CharacterCodingException$class_object;

#endif	/* _JC_java_nio_charset_CharacterCodingException_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/CharacterCodingException.h <==
// public class java.nio.charset.CharacterCodingException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c9c34a3e4ea2cab5 java_nio_charset_CharacterCodingException

// header file dependencies
// @dep_header java_io_IOException

#include "java/io/IOException.h"

#ifndef _JC_java_nio_charset_CharacterCodingException_H_
#define _JC_java_nio_charset_CharacterCodingException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_charset_CharacterCodingException$sub_refs	_jc_java_nio_charset_CharacterCodingException$sub_refs;
typedef struct _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	_jc_java_nio_charset_CharacterCodingException$sub_nonrefs;
typedef struct _jc_java_nio_charset_CharacterCodingException$refs	_jc_java_nio_charset_CharacterCodingException$refs;
typedef struct _jc_java_nio_charset_CharacterCodingException$nonrefs	_jc_java_nio_charset_CharacterCodingException$nonrefs;
typedef struct _jc_java_nio_charset_CharacterCodingException$object	_jc_java_nio_charset_CharacterCodingException$object;

typedef const struct _jc_java_nio_charset_CharacterCodingException$vmethods	_jc_java_nio_charset_CharacterCodingException$vmethods;
typedef const struct _jc_java_nio_charset_CharacterCodingException$vtable	_jc_java_nio_charset_CharacterCodingException$vtable;
typedef const struct _jc_java_nio_charset_CharacterCodingException$vtype	_jc_java_nio_charset_CharacterCodingException$vtype;

// Constructors
extern void _jc_java_nio_charset_CharacterCodingException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_charset_CharacterCodingException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_charset_CharacterCodingException$vmethods {
};

// Vtable
struct _jc_java_nio_charset_CharacterCodingException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_nio_charset_CharacterCodingException$vmethods	java_nio_charset_CharacterCodingException;
};

// Vtype
struct _jc_java_nio_charset_CharacterCodingException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_CharacterCodingException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_CharacterCodingException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_charset_CharacterCodingException$refs {
    _jc_java_nio_charset_CharacterCodingException$sub_refs	java_nio_charset_CharacterCodingException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_CharacterCodingException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_CharacterCodingException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_nio_charset_CharacterCodingException$sub_nonrefs	java_nio_charset_CharacterCodingException;
};

// Object instance structure
struct _jc_java_nio_charset_CharacterCodingException$object {
	_jc_java_nio_charset_CharacterCodingException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_CharacterCodingException$vtype	*vtype;
	_jc_java_nio_charset_CharacterCodingException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_CharacterCodingException$vtype _jc_java_nio_charset_CharacterCodingException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_CharacterCodingException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_CharacterCodingException$class_object;

#endif	/* _JC_java_nio_charset_CharacterCodingException_H_ */
